@echo off
rem :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
rem : BEGIN customization

rem : The folder to store copies of the registry files:
set _BACKUPDIR_=C:\REGBKUP

rem : The folder in which Windows is installed:
set _WINDIR_=C:\WINDOWS

rem : The root folder for user profiles
set _PROFILESDIR_=%_WINDIR_%\Profiles

rem : The list of user names whose registries should be backed up,
rem : separated with spaces, like: set _USERLIST_=John Mark Sue
rem : Set to (none) to skip this part, like: set _USERLIST_=(none)
set _USERLIST_=(none)

rem : END customization
rem :::::::::::::::::::::::::::::::::::::::::::::::::::::::

echo --------------------------------------------------------------------
echo Simple Registry Backup/Restore utility        [Ver.1.1 - 02/15/1999]
echo Copyright (c) 1997-99, WinAbility.Com. All rights reserved.
echo --------------------------------------------------------------------

goto _start

:_message

echo --------------------------------------------------------------------
echo Usage: enter at the MS-DOS command prompt (in MS-DOS mode only!):
echo   REGISTRY BACKUP  - to back up the registry
echo   REGISTRY RESTORE - to restore the registry
echo --------------------------------------------------------------------
echo Attention: this utility is set up to use the following information:
echo           Registry backup folder: %_BACKUPDIR_%
echo                   Windows folder: %_WINDIR_%
echo    Root folder for user profiles: %_PROFILESDIR_%
echo                    List of users: %_USERLIST_%
echo If your system configuration is different, edit 'REGISTRY.BAT'!
echo ---------------------------------------------------------------------

goto _exit

:_start

rem : Verify that _WINDIR_ specifies valid Windows folder
rem : (the folder must contain WIN.COM)

if exist %_WINDIR_%\WIN.COM goto _01
echo E R R O R : Invalid Windows folder specified: '%_WINDIR_%'
echo Edit 'REGISTRY.BAT' !
goto _exit
:_01

rem : Verify that the Profiles folder exists, if specified
if [%_PROFILESDIR_%]==[_] goto _02
if exist %_PROFILESDIR_%\NUL goto _02
echo Cannot find the Profiles folder specified: '%_PROFILESDIR_%'
echo Press any key to continue and SKIP processing the user profiles
echo or press Ctrl+Break to abort
pause > NUL
set _PROFILESDIR_=_
:_02

rem: Analyze the command line arguments supplied

if [%2]==[] goto _04
echo E R R O R : Too many command line arguments specified
goto _message
:_04

if not [%1]==[] goto _05
echo E R R O R : No command line argument specified
goto _message
:_05

rem : Validate the argument passed

if [%1]==[BACKUP] goto _do_work
if [%1]==[backup] goto _do_work
if [%1]==[RESTORE] goto _do_work
if [%1]==[restore] goto _do_work

echo E R R O R: Invalid command line argument: '%1'
goto _message

:_do_work

rem : Make sure we are running in MS-DOS mode
if [%windir%]==[] goto _06
echo E R R O R: Cannot backup/restore registry while Windows is running.
goto _exit
:_06

if [%1]==[BACKUP] goto _backup
if [%1]==[backup] goto _backup
if [%1]==[RESTORE] goto _restore
if [%1]==[restore] goto _restore

rem :::::::::::::::::::::::::::::::
rem ::  Backing up the Registry  ::
rem :::::::::::::::::::::::::::::::

:_backup

echo This will backup System.dat and User.dat into the folder:
echo   %_BACKUPDIR_%
echo Assuming Windows is installed in folder:
echo   %_WINDIR_%

if [%_USERLIST_%]==[(none)] goto _07
echo Also will backup User.dat file(s) for user(s):
echo   %_USERLIST_%
echo Assuming user profiles are located in subfolders of:
echo   %_PROFILESDIR_%
:_07

echo Press any key to continue or Ctrl+Break to abort.
echo --------------------------------------------------------------------
pause > NUL

rem : create the backup folder if it does not exist

if exist %_BACKUPDIR_%\NUL goto _09
md %_BACKUPDIR_%

:_09

echo * Backing up %_WINDIR_%\System.dat...
attrib -R -S -H %_WINDIR_%\System.dat
copy /Y %_WINDIR_%\System.dat %_BACKUPDIR_%
attrib +R +S +H %_WINDIR_%\System.dat

echo * Backing up %_WINDIR_%\User.dat...
attrib -R -S -H %_WINDIR_%\User.dat
copy /Y %_WINDIR_%\User.dat %_BACKUPDIR_%
attrib +R +S +H %_WINDIR_%\User.dat

if [%_USERLIST_%]==[(none)] goto _11

rem : Create subfolder to store user profiles
if exist %_BACKUPDIR_%\Profiles\NUL goto _10
cd %_BACKUPDIR_%
md Profiles
cd ..
:_10

for %%u in (%_USERLIST_%) do echo * Backing up %_PROFILESDIR_%\%%u\User.dat
for %%u in (%_USERLIST_%) do attrib -R -S -H %_PROFILESDIR_%\%%u\User.dat
cd %_BACKUPDIR_%\Profiles
for %%u in (%_USERLIST_%) do md %%u
for %%u in (%_USERLIST_%) do copy /Y %_PROFILESDIR_%\%%u\User.dat %_BACKUPDIR_%\Profiles\%%u\*.*
cd ..\..
for %%u in (%_USERLIST_%) do attrib +R +S +H %_PROFILESDIR_%\%%u\User.dat

:_11

goto _exit

rem ::::::::::::::::::::::::::::::
rem ::  Restoring the Registry  ::
rem ::::::::::::::::::::::::::::::

:_restore

if exist %_BACKUPDIR_%\NUL goto _12
echo E R R O R: Backup folder '%_BACKUPDIR_%' does not exist.
echo Edit 'REGISTRY.BAT' !
goto _exit
:_12

echo This will restore System.dat and User.dat from folder:
echo   %_BACKUPDIR_%
echo Assuming Windows is installed in folder:
echo   %_WINDIR_%

if [%_USERLIST_%]==[(none)] goto _13
echo Also will restore Used.dat file(s) for user(s):
echo   %_USERLIST_%
echo Assuming user profiles are located in subfolders of:
echo   %_PROFILESDIR_%
:_13

echo Press any key to continue or Ctrl+Break to abort.
echo --------------------------------------------------------------------
pause > NUL

echo * Restoring %_WINDIR_%\System.dat...
attrib -R -S -H %_WINDIR_%\System.dat
copy /Y %_BACKUPDIR_%\System.dat %_WINDIR_%
attrib +R +S +H %_WINDIR_%\System.dat

echo * Restoring %_WINDIR_%\User.dat...
attrib -R -S -H %_WINDIR_%\User.dat
copy /Y %_BACKUPDIR_%\User.dat %_WINDIR_%
attrib +R +S +H %_WINDIR_%\User.dat

if [%_USERLIST_%]==[(none)] goto _15
for %%u in (%_USERLIST_%) do echo * Restoring %_PROFILESDIR_%\%%u\User.dat

for %%u in (%_USERLIST_%) do attrib -R -S -H %_PROFILESDIR_%\%%u\User.dat
for %%u in (%_USERLIST_%) do copy /Y %_BACKUPDIR_%\Profiles\%%u\User.dat %_PROFILESDIR_%\%%u
for %%u in (%_USERLIST_%) do attrib +R +S +H %_PROFILESDIR_%\%%u\User.dat

:_15

goto _exit

:_exit

rem : Clean up the environment

set _BACKUPDIR_=
set _WINDIR_=
set _PROFILESDIR_=

pause
